@@ -19,7 +19,7 @@
 #ifndef QUINN_LIST_H
 #define QUINN_LIST_H
 
-#include "main.h"
+#include "common.h"
 
 typedef struct _quinn_list Qlist;
 
