@@ -24,21 +24,22 @@
 typedef struct _output_info output_info;
 
 struct _output_info {
-  char *name; 
-  char *source_version; 
-  char *binary_version; 
-  boolean compiled;
-  char *priority; 
-  char *section; 
+  char *name;
+  char *source_version;
+  char *binary_version;
+  boolean partial;
+  boolean missing;
+  char *priority;
+  char *section;
   int compare_versions_result;
-  int errors;
 };
 
 void output_ht_create (void);
 void output_ht_add (const sources_info *source, const char *binary_version,
 		    const int compare_versions_result);
-output_info *output_ht_retrieve (char *package);
+output_info *output_ht_retrieve (const char *package);
 void output_display_all(void);
+boolean output_ht_remove (const char *key);
 void output_ht_destroy(void);
 
 #endif /* __OUTPUT_H__ */
