@@ -18,6 +18,7 @@
 
 #include <stdlib.h>
 #include <string.h>
+#include <glib.h>
 #include "arch_specific.h"
 #include "error.h"
 #include "globals.h"
@@ -27,9 +28,6 @@
 #include "parse_sources.h"
 #include "utils.h"
 #include "vercmp.h"
-#include "xmalloc.h"
-
-void free_binaries (Qlist **list);
 
 void
 parse_sources (sources_info *source)
@@ -39,14 +37,14 @@ parse_sources (sources_info *source)
   Qlist *want_list, *list_temp;
   char *binary, *prefixed_source_name;
   packages_ht_info *binary_data;
-  int j,k,l, q;
+  int i, q;
   boolean is_different;
 
   /* Read the Sources file, comparing to the the hash table of the
      Packages file as we go. */
 
   want_list = NULL;
-  want_data = xmalloc (sizeof(*want_data));
+  want_data = g_malloc (sizeof(*want_data));
   strcpy (want_data->search_string, "Package: ");
   want_data->destination_string = &source->name;
   want_list = want_append (want_list, want_data);
@@ -74,15 +72,17 @@ parse_sources (sources_info *source)
 
       /* Check the entire source package is not excluded */
 
-      prefixed_source_name = xmalloc (strlen (source->name) + 2);
+      prefixed_source_name = g_malloc (strlen (source->name) + 2);
       sprintf (prefixed_source_name, "%%%s", source->name);
       q = is_arch_specific (prefixed_source_name);
-      xfree (prefixed_source_name);
-      if (q)
-	{
-	  xfree (source->name);
-	  continue;
-	}
+      g_free (prefixed_source_name);
+      if (q) {
+        g_free (source->name);
+        source->name = NULL;
+        continue;
+      }
+
+      g_strstrip (source->architecture);
 
       /* If we're ignoring 'Architecture: all' packages, check this isn't */
       if (ignore_arch_all && in_arch_list(source->architecture, "all")
@@ -95,10 +95,10 @@ parse_sources (sources_info *source)
       /* Sanity check source package's fields before continuing */
 
       if (!source->section)
-	source->section = xstrdup ("");
+	source->section = g_strdup ("");
 
       if (!source->priority)
-	source->priority = xstrdup ("-");
+	source->priority = g_strdup ("-");
 
       list_temp = want_find (want_list, "Version: ");
       if (!((want_node *)(list_temp->data))->found)
@@ -107,116 +107,77 @@ parse_sources (sources_info *source)
       debug(debug_sources, "parse_sources: priority = %s, section = %s, version = %s, binary = %s",
 	    source->priority, source->section, source->version, source->binary);
 
-      xfree_if_non_null (source->binaries);
-      if (!strchr(source->binary,','))
-	{
-	  /* We do this so we can consistently xfree the list's data nodes */
-	  binary = xstrdup (source->binary);
-	  source->binaries = qlist_append (source->binaries, binary);
-	}
-      else
-	{
-	  /* Dump the binary components into a linked list */
-
-	  /* This is horrible because strsep() isn't portable,
-	     strtok() isn't viable and I still can't get rid
-	     of my horrible over-optimizing habits */
-
-	  /* j = pointer into source->binary
-	     k = end of source->binary
-	     l = start of current binary in source->binary */
-	  j = 0;
-	  k = strlen (source->binary);
-	  l = 0;
-	  while (j <= k)
-	    {
-	      if (source->binary[j] == ',' || j == k)
-		{
-		  if (source->binary[l] == ' ')
-		    l++;
-		  binary = xmalloc (j-l+1);
-		  strncpy (binary, source->binary+l, j-l);
-		  binary[j-l] = '\0';
-		  source->binaries = qlist_append (source->binaries, binary);
-		  l = j+1;
-		}
-	      j++;
-	    }
-	}
-
       /* Process each binary */
 
-      list_temp = source->binaries;
-      while (list_temp)
-	{
-	  binary = list_temp->data;
-	  if (!is_arch_specific(binary))
-	    {
-	      binary_data = packages_ht_lookup (binary);
-	      is_different = FALSE;
-	      /* If this binary package is not compiled... */
-	      if (!binary_data)
-		{
-		  debug (debug_sources, "parse_sources: %s from %s is uncompiled...", binary, source->name);
-		  output_ht_add (source, NULL, 0);
-		  is_different = TRUE;
-		}
-	      /* If it is compiled, make sure it's the same version... */
-	      else
-		{
-		  if (strcmp (source->version, binary_data->version))
-		    {
-		      q = compare_versions (source->version, binary_data->version, source->name);
-		      /* If the binary is newer than the source, ensure it's a binary
-                         from this source package */
-		      if ((q >= 1) &&
-			  (binary_data->source && (strcmp (binary_data->source, source->name))))
-			debug(debug_sources, "parse_sources: %s is from %s, not %s and  is a newer version (%s vs. %s) too.", binary, binary_data->source, source->name, binary_data->version, source->version);
-		      else
-			{
-			  debug (debug_sources, "parse_sources: %s from %s is different version-wise (%d)...", binary, source->name, q);
-			  output_ht_add (source, binary_data->version, q);
-			  is_different = TRUE;
-			}
-		    }
-		  else
-		    {
-		      if (strcmp(binary_data->architecture, "all"))
-			output_ht_add (source, binary_data->version, 0);
-		    }
-		}
+      source->binaries = g_strsplit(source->binary, ",", 0);
+      for(i = 0; source->binaries[i]; ++i)
+      {
+        binary = g_strstrip(source->binaries[i]);
+        debug (debug_sources, "parse_sources: source %s: processing binary %s", source->name, binary);
 
-	      if (is_different &&
-		  !in_arch_list(source->architecture,packages_architecture) &&
-		  !in_arch_list(source->architecture,"any"))
-		error ("warning: %s has an architecture field of \"%s\" which doesn't include %s.", source->name, source->architecture+1, packages_architecture);
-	    }
-	  list_temp = list_temp->next;
-	}
+        if (is_arch_specific(binary))
+          continue;
 
-      free_binaries (&source->binaries);
+        /*
+         * If the Architecture list in the Sources file does not list the own
+         * architecture, then building is doomed to fail on the builder due
+         * to dpkg-dev aborting the build.  Thus log a debug message for each
+         * package not listed in P-a-s but still deactivated, but do not
+         * bother about them anymore.
+         */
+        if (!in_arch_list(source->architecture, packages_architecture) &&
+            !in_arch_list(source->architecture, "any") &&
+            strcmp(source->architecture, "all") != 0) {
+          if (!is_arch_specific(binary)) {
+            debug(debug_sources, "parse_sources: package %s: not buildable due to ('%s') but not listed in arch specific", source->name, source->architecture);
+          }
+          debug(debug_sources, "parse_sources: ignoring package %s: neither %s nor any nor all in ('%s')", source->name, packages_architecture, source->architecture);
+          continue;
+        }
 
+        binary_data = packages_ht_lookup (binary);
+        is_different = FALSE;
+
+        /* If this binary package is not compiled... */
+        if (!binary_data)
+        {
+          debug (debug_sources, "parse_sources: %s from %s is uncompiled...", binary, source->name);
+          output_ht_add (source, NULL, 0);
+          is_different = TRUE;
+        }
+        /* If it is compiled, make sure it's the same version... */
+        else
+        {
+          if (strcmp (source->version, binary_data->version))
+          {
+            q = compare_versions (source->version, binary_data->version, source->name);
+            /* If the binary is newer than the source, ensure it's a binary
+               from this source package */
+            if ((q >= 1) &&
+                (binary_data->source && (strcmp (binary_data->source, source->name))))
+            {
+              debug(debug_sources, "parse_sources: %s is from %s, not %s and  is a newer version (%s vs. %s) too.", binary, binary_data->source, source->name, binary_data->version, source->version);
+            }
+            else
+            {
+              debug (debug_sources, "parse_sources: %s from %s is different version-wise (%d)...", binary, source->name, q);
+              output_ht_add (source, binary_data->version, q);
+              is_different = TRUE;
+            }
+          }
+          else
+          {
+            if (strcmp(binary_data->architecture, "all"))
+              output_ht_add (source, binary_data->version, 0);
+          }
+        }
+      }
+
+      g_strfreev(source->binaries);
     }
 
+  source->binaries = NULL;
   qlist_destroy (want_list);
 
 }
 
-void
-free_binaries (Qlist **list)
-{
-
-  Qlist *previous;
-
-  if (!*list) return;
-
-  do
-    {
-      xfree_if_non_null ((*list)->data);
-      previous = *list;
-      *list = (*list)->next;
-      xfree (previous);
-    } while (*list);
-
-}
-
