@@ -23,7 +23,6 @@
 #include "error.h"
 #include "list.h"
 #include "utils.h"
-#include "xmalloc.h"
 
 /* Two common functions used by all the hash tables */
 
@@ -71,9 +70,8 @@ parse_package (const char *buffer, long buffer_position, const int buffer_length
 	       Qlist *want_list)
 {
 
-  char *line;
+  char *line, *temp_line;
   Qlist *want_list_pointer;
-  int i;
 
   /* Initialize the want list */
   want_list_pointer = want_list;
@@ -83,7 +81,7 @@ parse_package (const char *buffer, long buffer_position, const int buffer_length
       ((want_node *)(want_list_pointer->data))->found = FALSE;
       if (*((want_node *) want_list_pointer->data)->destination_string)
 	{
-	  xfree (*((want_node *) want_list_pointer->data)->destination_string);
+	  g_free (*((want_node *) want_list_pointer->data)->destination_string);
 	  *((want_node *) want_list_pointer->data)->destination_string = NULL;
 	}
       want_list_pointer = want_list_pointer->next;
@@ -95,16 +93,34 @@ parse_package (const char *buffer, long buffer_position, const int buffer_length
     {
       want_list_pointer = want_list;
 
-      /* We're not interested in descriptions, so we skip any lines that start with a space. */
+      /* If we ignored a line continuation before, ignore them here too. */
       if (buffer[buffer_position] == ' ')
-	{
-	  skip_line(buffer, &buffer_position, buffer_length);
-	  continue;
-	}
+      {
+        skip_line(buffer, &buffer_position, buffer_length);
+        continue;
+      }
 
-      i = 0;
+      line = NULL;
+      do {
+        temp_line = read_line (buffer, buffer_length, &buffer_position);
+        if (strlen(temp_line) == 0)
+          break;
 
-      line = read_line (buffer, buffer_length, &buffer_position);
+        /* Skip the description */
+        if (strncmp(temp_line, "Description: ", 13) == 0)
+          break;
+
+        if (line != NULL) {
+          temp_line = g_strjoin(NULL, line, temp_line + 1, NULL);
+          g_free(line);
+          debug (debug_utils, "parse_package: line continuation: %s", temp_line);
+        }
+
+        line = temp_line;
+      } while(buffer_position < buffer_length && buffer[buffer_position] == ' ');
+
+      if (line == NULL)
+        continue;
 
       debug (debug_utils, "parse_package: |->'%s'", line);
       /* Check the want list, to see if the line we have is one we need. */
@@ -120,7 +136,7 @@ parse_package (const char *buffer, long buffer_position, const int buffer_length
 		{
 		  debug (debug_utils, "parse_package: match on  = %s", (((want_node *)(want_list_pointer->data))->search_string));
 		  *((want_node *) want_list_pointer->data)->destination_string =
-		    xstrdup (line + (strlen (((want_node *)(want_list_pointer->data))->search_string)));
+		    g_strdup (line + (strlen (((want_node *)(want_list_pointer->data))->search_string)));
 		  ((want_node *)(want_list_pointer->data))->found = TRUE;
 		  break;
 		}
@@ -129,7 +145,7 @@ parse_package (const char *buffer, long buffer_position, const int buffer_length
 	  want_list_pointer = want_list_pointer->next;
 	}
 
-      xfree (line);
+      g_free (line);
     }
 
   buffer_position++;
@@ -170,7 +186,7 @@ get_field (const char *buffer, const long buffer_length, long buffer_position,
 	    }
 	  else
 	    {
-	      xfree (field);
+	      g_free (field);
 	      field = NULL;
 	    }
 	}
@@ -214,14 +230,14 @@ read_line (const char *buffer, const long buffer_length, long *counter)
   int max_length = 256;
   char *line;
 
-  line = xmalloc (max_length);
+  line = g_malloc (max_length);
 
   while (*counter < buffer_length && buffer[*counter] != '\n')
     {
       if (i == max_length - 1)
 	{
 	  max_length *= 2;
-	  line = xrealloc (line, max_length);
+	  line = g_realloc (line, max_length);
 	}
       line[i++] = buffer[(*counter)++];
 
@@ -257,7 +273,7 @@ void read_file (const char *filename, FILE *fp, char **buffer_p, long *file_leng
       /* We don't do any memory management, we just ask for a chunk of
        * memory the size of the file */
 
-      *buffer_p = (char *) xmalloc (*file_length);
+      *buffer_p = (char *) g_malloc (*file_length);
 
       /* RUARI QUINN this is ignoring the possibility that ftell could be long */
       n_read = fread (*buffer_p, sizeof (char), *file_length, fp);
@@ -273,17 +289,6 @@ void read_file (const char *filename, FILE *fp, char **buffer_p, long *file_leng
 
 }
 
-char *
-xstrdup (const char *s)
-{
-  char *r;
-
-  r = strdup (s);
-  if (!r)
-    fubar (SYSERR, "xstrdup: memory exhausted.");
-  return r;
-}
-
 boolean
 in_arch_list(const char *arch_list, const char *arch)
 {
